==> prestashop_1.4.0.7.zip: prestashop/modules/socolissimo/fr.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{socolissimo}prestashop>socolissimo_42ab10dea7d96b9c353e0f5bae43ec20'] = 'La Poste';
$_MODULE['<{socolissimo}prestashop>socolissimo_52a54afe869c8412c8425548f4f4e938'] = 'Proposez à vos clients 5 modes de livraison via La Poste.';
$_MODULE['<{socolissimo}prestashop>socolissimo_6b1e653c64d5078a4d73ad8e0ac5afc0'] = 'Transporteur correspondance';
$_MODULE['<{socolissimo}prestashop>socolissimo_f8e355b97fa1be7a8d8c206aa66f0077'] = 'Zone(s) du transporteur';
$_MODULE['<{socolissimo}prestashop>socolissimo_690c1c6abf905b88281a7cd324af9942'] = 'Groupe du transporteur';
$_MODULE['<{socolissimo}prestashop>socolissimo_6c32f43085785c00dc7062017d365ca5'] = 'Tranche du transporteur';
$_MODULE['<{socolissimo}prestashop>socolissimo_59f26c70c0230e4ec5e4acdfed0e270c'] = 'Prix de tranche';
$_MODULE['<{socolissimo}prestashop>socolissimo_798547c41ec3e64e2322df678e939344'] = '\'Identifiant FO\'';
$_MODULE['<{socolissimo}prestashop>socolissimo_ac08649aa09ff3b879525627bf086dd1'] = '\'Clé de cryptage\'';
$_MODULE['<{socolissimo}prestashop>socolissimo_a3a53f075adf77334cc34d0f7497ff44'] = '\'Url de l\'administration de SoColissimo\'';
$_MODULE['<{socolissimo}prestashop>socolissimo_4d470fde8487e755a50e9235e3dc13ab'] = 'doivent être renseignés pour fonctionner correctement';
$_MODULE['<{socolissimo}prestashop>socolissimo_b0573388e2dd39a9555e2a7f4e06ed82'] = 'Clef de securité invalide';
$_MODULE['<{socolissimo}prestashop>socolissimo_8bc445c5419a72d64e926c047d777370'] = 'Une erreur s\'est produite lors de l\'étape transporteur';
$_MODULE['<{socolissimo}prestashop>socolissimo_70b2e65f0f2aabf3e2c58d70cf1e1e9a'] = 'Identifiant FO manquant';
$_MODULE['<{socolissimo}prestashop>socolissimo_6bb5ba0658b8d93494eace620675e25c'] = 'Identifiant FO incorrect';
$_MODULE['<{socolissimo}prestashop>socolissimo_7ca12228b5ad636c637425a086fe0092'] = 'Client non autorise';
$_MODULE['<{socolissimo}prestashop>socolissimo_0b1d0c0a00cc2727fcd77902867e3641'] = 'Champs obligatoire manquant';
$_MODULE['<{socolissimo}prestashop>socolissimo_fa419073252af9d022afe65dccbb34a2'] = 'Signature manquante';
$_MODULE['<{socolissimo}prestashop>socolissimo_fca3fbced675f75182786525bf4706dc'] = 'Signature invalide';
$_MODULE['<{socolissimo}prestashop>socolissimo_5f725a1d45e99d248b0426177def2793'] = 'Code postal invalide';
$_MODULE['<{socolissimo}prestashop>socolissimo_7359b41a73f544cd2238ae3577ad742f'] = 'Format url retour Validation incorrect';
$_MODULE['<{socolissimo}prestashop>socolissimo_74780d82c0afc195aa35d5bf1c8ba9fe'] = 'Format url retour Echec incorrect';
$_MODULE['<{socolissimo}prestashop>socolissimo_6ac5d959c1041bb76fa0a836a3bd90ed'] = 'Invalid transaction number';
$_MODULE['<{socolissimo}prestashop>socolissimo_68c74dc0c1c19125aa53b1e1bac6a426'] = ' Format des frais d’expédition incorrect';
$_MODULE['<{socolissimo}prestashop>socolissimo_dcdd8442c637eac078770bfbcd1ad577'] = 'Serveur Socolissimo non disponible';
$_MODULE['<{socolissimo}prestashop>socolissimo_b5a7adde1af5c87d7fd797b6245c2a39'] = 'Description';
$_MODULE['<{socolissimo}prestashop>socolissimo_f9bb2808d4b756fec1de88a30a83f4ba'] = 'So Colissimo est un service proposé par La Poste, qui vous permet d\'offrir à vos acheteurs 5 modes de livraison :';
$_MODULE['<{socolissimo}prestashop>socolissimo_b744007f56f155926b4584feb2570e14'] = 'Livraison à Domicile';
$_MODULE['<{socolissimo}prestashop>socolissimo_af34585e0c846008761f29c785cb3b6e'] = 'Livraison à Domicile sur Rendez-vous le soir entre 17h et 21h30';
$_MODULE['<{socolissimo}prestashop>socolissimo_6dabb6e301597ccf0ba5abda94748b05'] = 'Livraison dans l\'un des 31 espaces Cityssimo, 7j/7 et 24h/24';
$_MODULE['<{socolissimo}prestashop>socolissimo_45fb6b9ed318ed9f9c44a41026565f53'] = 'Livraison dans l\'un des 10.000 Bureaux de Poste de leur choix';
$_MODULE['<{socolissimo}prestashop>socolissimo_495b9fc0ac8760876f3738055e5c377e'] = 'Livraison dans l\'un des nombreux point de retrait du réseau partenaire La Poste';
$_MODULE['<{socolissimo}prestashop>socolissimo_890b8c64ae7c201fa0fca0ef55229054'] = 'Ce module est gratuit et vous permet d\'activer cette offre sur votre magasin.';
$_MODULE['<{socolissimo}prestashop>socolissimo_5b6cf869265c13af8566f192b4ab3d2a'] = 'Documentation';
$_MODULE['<{socolissimo}prestashop>socolissimo_f4f70727dc34561dfde1a3c529b6205c'] = 'Configuration';
$_MODULE['<{socolissimo}prestashop>socolissimo_0ab984d91ab0a037bdf692bf0e73c349'] = 'Important';
$_MODULE['<{socolissimo}prestashop>socolissimo_935c46da30477b9c68df2f8a8728ab7e'] = 'Pour l\'ouverture de votre compte So Colissimo, veuillez contacter votre interlocuteur commercial La Poste habituel ou le 3634';
$_MODULE['<{socolissimo}prestashop>socolissimo_9c85d4c2bae6ab548fe23e57bd89ddc4'] = 'Identifiant FO';
$_MODULE['<{socolissimo}prestashop>socolissimo_7b95472e0575adc1e3d90a2d7b51e496'] = 'Utilisateur So Colissimo';
$_MODULE['<{socolissimo}prestashop>socolissimo_897356954c2cd3d41b221e3f24f99bba'] = 'Clé de cryptage';
$_MODULE['<{socolissimo}prestashop>socolissimo_fe78e0a947bf1e0c9e0d9485f40e69cb'] = 'Clé de cryptage So Colissimo';
$_MODULE['<{socolissimo}prestashop>socolissimo_64979b52d796defbdf05356df9e37d57'] = 'Temps de préparation';
$_MODULE['<{socolissimo}prestashop>socolissimo_c76660d589be9a49e8846e51b71744ae'] = 'Jour(s)';
$_MODULE['<{socolissimo}prestashop>socolissimo_fee5b44342f1173f7a92b97ace566e57'] = 'Délai moyen de préparation de vos commandes';
$_MODULE['<{socolissimo}prestashop>socolissimo_25a997f8f21d9a0ec24e902baf9a99c0'] = 'Le délai de préparation de commande doit être identique à celui saisi dans le Back Office ColiPoste';
$_MODULE['<{socolissimo}prestashop>socolissimo_31e3fd47be6f64fb2e0a4f85cb63a069'] = 'Surcoût';
$_MODULE['<{socolissimo}prestashop>socolissimo_5f2b3818a8226aa853fc45c83783b12d'] = 'Taxe :';
$_MODULE['<{socolissimo}prestashop>socolissimo_7475ec0d41372a307c497acb7eeea8c4'] = 'Pas de taxe';
$_MODULE['<{socolissimo}prestashop>socolissimo_a68e8fd6d255edb0ca099c7400252694'] = 'Surcoût à appliquer pour la livraison à domicile sur rendez-vous';
$_MODULE['<{socolissimo}prestashop>socolissimo_5b8aa3268fe97228ab7337ef8cdabfb5'] = 'Le \"surcoût\" doit être identique à celui saisi dans le Back Office ColiPoste';
$_MODULE['<{socolissimo}prestashop>socolissimo_914419aa32f04011357d3b604a86d7eb'] = 'Transporteur';
$_MODULE['<{socolissimo}prestashop>socolissimo_3a13414c2308a98553c185fadb866b5e'] = 'Choix du transporteur';
$_MODULE['<{socolissimo}prestashop>socolissimo_323f1dd8e745f4a83e34713442551d2a'] = 'Choisir le transporteur So colissimo dans la liste.';
$_MODULE['<{socolissimo}prestashop>socolissimo_818dbcbfb3aad51ddcc1252657537573'] = 'Le transporteur So Colissimo n\'est pas choisit.';
$_MODULE['<{socolissimo}prestashop>socolissimo_06db62a9266228955b3b86e1125d71b7'] = 'Soyez très prudent avec ces paramètres, le changement peut provoquer un dysfonctionnement du module';
$_MODULE['<{socolissimo}prestashop>socolissimo_b0b2896e75025245cbb05e96bd1466d6'] = 'Adresse FO';
$_MODULE['<{socolissimo}prestashop>socolissimo_ce88aabea3b363c753b02ddcb2fbafff'] = 'Url de l\'administration de So Colissimo';
$_MODULE['<{socolissimo}prestashop>socolissimo_85068ddf0b9bcbb6913008356fe328a0'] = 'Supervision';
$_MODULE['<{socolissimo}prestashop>socolissimo_00d23a76e43b46dae9ec7aa9dcbebb32'] = 'Activé';
$_MODULE['<{socolissimo}prestashop>socolissimo_b9f5c797ebbf55adccdd8539a65a0241'] = 'Désactivé';
$_MODULE['<{socolissimo}prestashop>socolissimo_060823982d2849648aa0e1fb01144e6f'] = 'Autoriser ou non la verification de la disponibilité des services SoColissimo';
$_MODULE['<{socolissimo}prestashop>socolissimo_32996bdf4214d6cb8bf7fa02273813c8'] = 'Adresse de verification';
$_MODULE['<{socolissimo}prestashop>socolissimo_995a56aecac4198b9bc0a17a976561b5'] = 'Adresse de verification de disponibilité';
$_MODULE['<{socolissimo}prestashop>socolissimo_c9cc8cce247e49bae79f15173ce97354'] = 'Sauvegarder';
$_MODULE['<{socolissimo}prestashop>socolissimo_c4c95c36570d5a8834be5e88e2f0f6b2'] = 'Informations';
$_MODULE['<{socolissimo}prestashop>socolissimo_1f34ece27228b13a764f29cf5b07592d'] = 'Voici les deux adresses que vous devez renseigner dans votre Back-Office Coliposte';
$_MODULE['<{socolissimo}prestashop>socolissimo_49977cbb6772deeac9ceb89f069e491c'] = 'Url de validation';
$_MODULE['<{socolissimo}prestashop>socolissimo_06dc3f24f73027164d2b19556118624e'] = 'Url de retour';
$_MODULE['<{socolissimo}prestashop>socolissimo_82c440defe28e2099cba1af1f0761807'] = 'Identifiant FO non spécifié';
$_MODULE['<{socolissimo}prestashop>socolissimo_826361881cfc18b8b75405d398f633b5'] = 'Clé de cryptage non spécifié';
$_MODULE['<{socolissimo}prestashop>socolissimo_0bf6a620e5f22d8b46e3903a993f7741'] = 'Temps de préparation non spécifié';
$_MODULE['<{socolissimo}prestashop>socolissimo_b1da6deb76f499bdcdbb9f1e28223ff6'] = 'Temps de préparation invalide';
$_MODULE['<{socolissimo}prestashop>socolissimo_5b1ea9a874e8e67af093b45ad34be1bd'] = 'Surcoût non spécifié';
$_MODULE['<{socolissimo}prestashop>socolissimo_ccdfd8ad75276f6e24db51d02e83e361'] = 'Surcoût invalide';
$_MODULE['<{socolissimo}prestashop>socolissimo_20015706a8cbd457cbb6ea3e7d5dc9b3'] = 'Configuration mise à jour';
$_MODULE['<{socolissimo}prestashop>socolissimo_738a1d4da1b5dc5883063ec9856b637b'] = 'Configuration erreur';
$_MODULE['<{socolissimo}prestashop>socolissimo_201bdb87f8e278b943d07ae924d5de6e'] = 'Mode de livraison';
$_MODULE['<{socolissimo}prestashop>socolissimo_ce26601dac0dea138b7295f02b7620a7'] = 'Client';
$_MODULE['<{socolissimo}prestashop>socolissimo_7ad19f92a4021a80dbf91bbd28a68114'] = 'Societe';
$_MODULE['<{socolissimo}prestashop>socolissimo_ce8ae9da5b7cd6c3df2929543a9af92d'] = 'Email';
$_MODULE['<{socolissimo}prestashop>socolissimo_2e006b735fbd916d8ab26978ae6714d4'] = 'Tel';
$_MODULE['<{socolissimo}prestashop>socolissimo_fa3013139b3eec5e406293d260d4b9dd'] = 'Adresse du client';
$_MODULE['<{socolissimo}prestashop>socolissimo_6311ae17c1ee52b36e68aaf4ad066387'] = 'Autre';
$_MODULE['<{socolissimo}prestashop>socolissimo_d676596f71fd0f73f735da4bb4225151'] = 'Code de la porte';
$_MODULE['<{socolissimo}prestashop>socolissimo_71736f329d8ecb6bdb8ab29875ed7d27'] = 'Informations sur la livraison';
$_MODULE['<{socolissimo}prestashop>socolissimo_26c3322326d6c253776082396d0b525a'] = 'Id du point de retrait';
$_MODULE['<{socolissimo}prestashop>socolissimo_fe0ddc6b5ddddfa1203a1931726a06b4'] = 'Point de retrait';
$_MODULE['<{socolissimo}prestashop>socolissimo_943d641a55c5f1a32331d21104cd7637'] = 'Adresse du point de retrait';

==> prestashop_1.4.0.9.zip: prestashop/modules/socolissimo/fr.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{socolissimo}prestashop>socolissimo_42ab10dea7d96b9c353e0f5bae43ec20'] = 'La Poste';
$_MODULE['<{socolissimo}prestashop>socolissimo_52a54afe869c8412c8425548f4f4e938'] = 'Proposez à vos clients 5 modes de livraison via La Poste.';
$_MODULE['<{socolissimo}prestashop>socolissimo_f8e355b97fa1be7a8d8c206aa66f0077'] = 'Zone(s) du transporteur';
$_MODULE['<{socolissimo}prestashop>socolissimo_690c1c6abf905b88281a7cd324af9942'] = 'Groupe du transporteur';
$_MODULE['<{socolissimo}prestashop>socolissimo_6c32f43085785c00dc7062017d365ca5'] = 'Tranche du transporteur';
$_MODULE['<{socolissimo}prestashop>socolissimo_59f26c70c0230e4ec5e4acdfed0e270c'] = 'Prix de tranche';
$_MODULE['<{socolissimo}prestashop>socolissimo_798547c41ec3e64e2322df678e939344'] = '\'Identifiant FO\'';
$_MODULE['<{socolissimo}prestashop>socolissimo_ac08649aa09ff3b879525627bf086dd1'] = '\'Clé de cryptage\'';
$_MODULE['<{socolissimo}prestashop>socolissimo_a3a53f075adf77334cc34d0f7497ff44'] = '\'Url de l\'administration de SoColissimo\'';
$_MODULE['<{socolissimo}prestashop>socolissimo_4d470fde8487e755a50e9235e3dc13ab'] = 'doivent être renseignés pour fonctionner correctement';
$_MODULE['<{socolissimo}prestashop>socolissimo_b0573388e2dd39a9555e2a7f4e06ed82'] = 'Clef de securité invalide';
$_MODULE['<{socolissimo}prestashop>socolissimo_8bc445c5419a72d64e926c047d777370'] = 'Une erreur s\'est produite lors de l\'étape transporteur';
$_MODULE['<{socolissimo}prestashop>socolissimo_70b2e65f0f2aabf3e2c58d70cf1e1e9a'] = 'Identifiant FO manquant';
$_MODULE['<{socolissimo}prestashop>socolissimo_6bb5ba0658b8d93494eace620675e25c'] = 'Identifiant FO incorrect';
$_MODULE['<{socolissimo}prestashop>socolissimo_7ca12228b5ad636c637425a086fe0092'] = 'Client non autorise';
$_MODULE['<{socolissimo}prestashop>socolissimo_0b1d0c0a00cc2727fcd77902867e3641'] = 'Champs obligatoire manquant';
$_MODULE['<{socolissimo}prestashop>socolissimo_fa419073252af9d022afe65dccbb34a2'] = 'Signature manquante';
$_MODULE['<{socolissimo}prestashop>socolissimo_fca3fbced675f75182786525bf4706dc'] = 'Signature invalide';
$_MODULE['<{socolissimo}prestashop>socolissimo_5f725a1d45e99d248b0426177def2793'] = 'Code postal invalide';
$_MODULE['<{socolissimo}prestashop>socolissimo_7359b41a73f544cd2238ae3577ad742f'] = 'Format url retour Validation incorrect';
$_MODULE['<{socolissimo}prestashop>socolissimo_74780d82c0afc195aa35d5bf1c8ba9fe'] = 'Format url retour Echec incorrect';
$_MODULE['<{socolissimo}prestashop>socolissimo_6ac5d959c1041bb76fa0a836a3bd90ed'] = 'Invalid transaction number';
$_MODULE['<{socolissimo}prestashop>socolissimo_68c74dc0c1c19125aa53b1e1bac6a426'] = ' Format des frais d’expédition incorrect';
$_MODULE['<{socolissimo}prestashop>socolissimo_dcdd8442c637eac078770bfbcd1ad577'] = 'Serveur Socolissimo non disponible';
$_MODULE['<{socolissimo}prestashop>socolissimo_b5a7adde1af5c87d7fd797b6245c2a39'] = 'Description';
$_MODULE['<{socolissimo}prestashop>socolissimo_f9bb2808d4b756fec1de88a30a83f4ba'] = 'So Colissimo est un service proposé par La Poste, qui vous permet d\'offrir à vos acheteurs 5 modes de livraison :';
$_MODULE['<{socolissimo}prestashop>socolissimo_b744007f56f155926b4584feb2570e14'] = 'Livraison à Domicile';
$_MODULE['<{socolissimo}prestashop>socolissimo_af34585e0c846008761f29c785cb3b6e'] = 'Livraison à Domicile sur Rendez-vous le soir entre 17h et 21h30';
$_MODULE['<{socolissimo}prestashop>socolissimo_6dabb6e301597ccf0ba5abda94748b05'] = 'Livraison dans l\'un des 31 espaces Cityssimo, 7j/7 et 24h/24';
$_MODULE['<{socolissimo}prestashop>socolissimo_45fb6b9ed318ed9f9c44a41026565f53'] = 'Livraison dans l\'un des 10.000 Bureaux de Poste de leur choix';
$_MODULE['<{socolissimo}prestashop>socolissimo_495b9fc0ac8760876f3738055e5c377e'] = 'Livraison dans l\'un des nombreux point de retrait du réseau partenaire La Poste';
$_MODULE['<{socolissimo}prestashop>socolissimo_890b8c64ae7c201fa0fca0ef55229054'] = 'Ce module est gratuit et vous permet d\'activer cette offre sur votre magasin.';
$_MODULE['<{socolissimo}prestashop>socolissimo_5b6cf869265c13af8566f192b4ab3d2a'] = 'Documentation';
$_MODULE['<{socolissimo}prestashop>socolissimo_f4f70727dc34561dfde1a3c529b6205c'] = 'Configuration';
$_MODULE['<{socolissimo}prestashop>socolissimo_0ab984d91ab0a037bdf692bf0e73c349'] = 'Important';
$_MODULE['<{socolissimo}prestashop>socolissimo_935c46da30477b9c68df2f8a8728ab7e'] = 'Pour l\'ouverture de votre compte So Colissimo, veuillez contacter votre interlocuteur commercial La Poste habituel ou le 3634';
$_MODULE['<{socolissimo}prestashop>socolissimo_9c85d4c2bae6ab548fe23e57bd89ddc4'] = 'Identifiant FO';
$_MODULE['<{socolissimo}prestashop>socolissimo_7b95472e0575adc1e3d90a2d7b51e496'] = 'Utilisateur So Colissimo';
$_MODULE['<{socolissimo}prestashop>socolissimo_897356954c2cd3d41b221e3f24f99bba'] = 'Clé de cryptage';
$_MODULE['<{socolissimo}prestashop>socolissimo_fe78e0a947bf1e0c9e0d9485f40e69cb'] = 'Clé de cryptage So Colissimo';
$_MODULE['<{socolissimo}prestashop>socolissimo_64979b52d796defbdf05356df9e37d57'] = 'Temps de préparation';
$_MODULE['<{socolissimo}prestashop>socolissimo_c76660d589be9a49e8846e51b71744ae'] = 'Jour(s)';
$_MODULE['<{socolissimo}prestashop>socolissimo_fee5b44342f1173f7a92b97ace566e57'] = 'Délai moyen de préparation de vos commandes';
$_MODULE['<{socolissimo}prestashop>socolissimo_25a997f8f21d9a0ec24e902baf9a99c0'] = 'Le délai de préparation de commande doit être identique à celui saisi dans le Back Office ColiPoste';
$_MODULE['<{socolissimo}prestashop>socolissimo_31e3fd47be6f64fb2e0a4f85cb63a069'] = 'Surcoût';
$_MODULE['<{socolissimo}prestashop>socolissimo_a68e8fd6d255edb0ca099c7400252694'] = 'Surcoût à appliquer pour la livraison à domicile sur rendez-vous';
$_MODULE['<{socolissimo}prestashop>socolissimo_5b8aa3268fe97228ab7337ef8cdabfb5'] = 'Le \"surcoût\" doit être identique à celui saisi dans le Back Office ColiPoste';
$_MODULE['<{socolissimo}prestashop>socolissimo_06db62a9266228955b3b86e1125d71b7'] = 'Soyez très prudent avec ces paramètres, le changement peut provoquer un dysfonctionnement du module';
$_MODULE['<{socolissimo}prestashop>socolissimo_b0b2896e75025245cbb05e96bd1466d6'] = 'Adresse FO';
$_MODULE['<{socolissimo}prestashop>socolissimo_ce88aabea3b363c753b02ddcb2fbafff'] = 'Url de l\'administration de So Colissimo';
$_MODULE['<{socolissimo}prestashop>socolissimo_85068ddf0b9bcbb6913008356fe328a0'] = 'Supervision';
$_MODULE['<{socolissimo}prestashop>socolissimo_00d23a76e43b46dae9ec7aa9dcbebb32'] = 'Activé';
$_MODULE['<{socolissimo}prestashop>socolissimo_b9f5c797ebbf55adccdd8539a65a0241'] = 'Désactivé';
$_MODULE['<{socolissimo}prestashop>socolissimo_060823982d2849648aa0e1fb01144e6f'] = 'Autoriser ou non la verification de la disponibilité des services SoColissimo';
$_MODULE['<{socolissimo}prestashop>socolissimo_32996bdf4214d6cb8bf7fa02273813c8'] = 'Adresse de verification';
$_MODULE['<{socolissimo}prestashop>socolissimo_995a56aecac4198b9bc0a17a976561b5'] = 'Adresse de verification de disponibilité';
$_MODULE['<{socolissimo}prestashop>socolissimo_c9cc8cce247e49bae79f15173ce97354'] = 'Sauvegarder';
$_MODULE['<{socolissimo}prestashop>socolissimo_c4c95c36570d5a8834be5e88e2f0f6b2'] = 'Informations';
$_MODULE['<{socolissimo}prestashop>socolissimo_1f34ece27228b13a764f29cf5b07592d'] = 'Voici les deux adresses que vous devez renseigner dans votre Back-Office Coliposte';
$_MODULE['<{socolissimo}prestashop>socolissimo_49977cbb6772deeac9ceb89f069e491c'] = 'Url de validation';
$_MODULE['<{socolissimo}prestashop>socolissimo_06dc3f24f73027164d2b19556118624e'] = 'Url de retour';
$_MODULE['<{socolissimo}prestashop>socolissimo_82c440defe28e2099cba1af1f0761807'] = 'Identifiant FO non spécifié';
$_MODULE['<{socolissimo}prestashop>socolissimo_826361881cfc18b8b75405d398f633b5'] = 'Clé de cryptage non spécifié';
$_MODULE['<{socolissimo}prestashop>socolissimo_0bf6a620e5f22d8b46e3903a993f7741'] = 'Temps de préparation non spécifié';
$_MODULE['<{socolissimo}prestashop>socolissimo_b1da6deb76f499bdcdbb9f1e28223ff6'] = 'Temps de préparation invalide';
$_MODULE['<{socolissimo}prestashop>socolissimo_5b1ea9a874e8e67af093b45ad34be1bd'] = 'Surcoût non spécifié';
$_MODULE['<{socolissimo}prestashop>socolissimo_ccdfd8ad75276f6e24db51d02e83e361'] = 'Surcoût invalide';
$_MODULE['<{socolissimo}prestashop>socolissimo_20015706a8cbd457cbb6ea3e7d5dc9b3'] = 'Configuration mise à jour';
$_MODULE['<{socolissimo}prestashop>socolissimo_738a1d4da1b5dc5883063ec9856b637b'] = 'Configuration erreur';
$_MODULE['<{socolissimo}prestashop>socolissimo_f8b0594014f40c058e19a5f8ecd67c2b'] = 'Pour choisir So Colissimo, merci de choisir une méthode de livraison ci-contre';
$_MODULE['<{socolissimo}prestashop>socolissimo_201bdb87f8e278b943d07ae924d5de6e'] = 'Mode de livraison';
$_MODULE['<{socolissimo}prestashop>socolissimo_ce26601dac0dea138b7295f02b7620a7'] = 'Client';
$_MODULE['<{socolissimo}prestashop>socolissimo_7ad19f92a4021a80dbf91bbd28a68114'] = 'Societe';
$_MODULE['<{socolissimo}prestashop>socolissimo_ce8ae9da5b7cd6c3df2929543a9af92d'] = 'Email';
$_MODULE['<{socolissimo}prestashop>socolissimo_2e006b735fbd916d8ab26978ae6714d4'] = 'Tel';
$_MODULE['<{socolissimo}prestashop>socolissimo_fa3013139b3eec5e406293d260d4b9dd'] = 'Adresse du client';
$_MODULE['<{socolissimo}prestashop>socolissimo_6311ae17c1ee52b36e68aaf4ad066387'] = 'Autre';
$_MODULE['<{socolissimo}prestashop>socolissimo_d676596f71fd0f73f735da4bb4225151'] = 'Code de la porte';
$_MODULE['<{socolissimo}prestashop>socolissimo_71736f329d8ecb6bdb8ab29875ed7d27'] = 'Informations sur la livraison';
$_MODULE['<{socolissimo}prestashop>socolissimo_26c3322326d6c253776082396d0b525a'] = 'Id du point de retrait';
$_MODULE['<{socolissimo}prestashop>socolissimo_fe0ddc6b5ddddfa1203a1931726a06b4'] = 'Point de retrait';
$_MODULE['<{socolissimo}prestashop>socolissimo_943d641a55c5f1a32331d21104cd7637'] = 'Adresse du point de retrait';
